#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
File: mask.py
Description: Mask section of the Sparshik KYC API.
"""

from .utils import request


def mask_aadhaar(file_path=None, image_url=None, data_uri=None):
	""" Mask aadhaar data.

	Args:
		file_path : [Optional] Path to File or Image or Data URL
		image_url : [Optional] data_uri or image_url or file_path ( one of them is required)
		data_uri : [Optional] data_uri or image_url or file_path ( one of them is required)

	Returns:
		masked data and returns HTTP status code
	"""
	url = "aadhaar/mask"
	json = {}

	if file_path:
		files = {'file_path': open(file_path, 'rb')}
	else:
		files = {}

	if image_url:
		json["image_url"] = image_url
	elif data_uri:
		json["data_uri"] = data_uri

	# call internal abstract API function
	response = request('POST', url, files=files, json=json)
	return response



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
File: setup.py
Description: Setup script to build and distribute sparshik-kyc module.
"""
import re
import os.path
from io import open
from setuptools import find_packages, setup

# Change the PACKAGE_NAME only to change folder and different name
PACKAGE_NAME = "sparshik-kyc"
PACKAGE_PPRINT_NAME = "Sparshik KYC"

# a-b-c => a/b/c
package_folder_path = PACKAGE_NAME.replace('-', '/')
# a-b-c => a.b.c
namespace_name = PACKAGE_NAME.replace('-', '.')

# Version extraction inspired from 'requests'
with open(os.path.join(package_folder_path, 'version.py')
		  if os.path.exists(os.path.join(package_folder_path, 'version.py'))
		  else os.path.join(package_folder_path, '_version.py'), 'r') as fd:
	version = re.search(r'^VERSION\s*=\s*[\'"]([^\'"]*)[\'"]',
						fd.read(), re.MULTILINE).group(1)

if not version:
	raise RuntimeError('Cannot find version information')

with open('README.md', encoding='utf-8') as f:
	readme = f.read()
with open('CHANGELOG.md', encoding='utf-8') as f:
	changelog = f.read()

setup(
	name=PACKAGE_NAME,
	version=version,
	packages=find_packages(),
	description="Python SDK for Sparshik KYC API",
	long_description=readme + '\n\n' + changelog,
	long_description_content_type="text/markdown",
	url="https://github.com/sparshik/kyc-sdk-python",
	license='MIT License',
	author='Sparshik Technologies',
	author_email='support@sparshik.com',
	classifiers=[
		'Development Status :: 3 - Alpha',
		'Intended Audience :: Developers',
		"License :: OSI Approved :: MIT License",
		"Programming Language :: Python :: 3",
		"Programming Language :: Python :: 3.5",
		"Programming Language :: Python :: 3.6",
		"Programming Language :: Python :: 3.7",
		'Topic :: Scientific/Engineering :: Image Recognition',
		'Topic :: Scientific/Engineering :: Artificial Intelligence',
		"Operating System :: OS Independent",
	],
	include_package_data=True,
	install_requires=['requests'],
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
File: challenge.py
Description: Challenge section of the Sparshik KYC API.
"""

from .utils import request


def create_challenge(applicant_id, document_id=None, user_request_id=None, delete_at=None):
	""" Creates a list of challenges for the user to tackle for verification purposes.

	Args:
		applicant_id : [Atleast one] document_id or applicant_id
		document_id : [Atleast one] document_id or applicant_id
		user_request_id : [Optional] user request id, supplied with response
		delete_at : [Optional] when to delete record, Ex, 14-07-2020

	Returns:
		applicant data from the database and returns HTTP status code
	"""
	url = "video/create_challenge/"
	files = None

	json = {'applicant_id': applicant_id, 'document_id': document_id,
			'user_request_id': user_request_id, 'delete_at': delete_at}

	# call internal abstract API function
	response = request('POST', url, files=files, json=json)
	return response



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
File: applicants.py
Description: Applicants section of the Sparshik KYC API.
"""

from .utils import request


def create_applicant(first_name, file_path=None, last_name=None, email=None, phone=None, dob=None, id_numbers=None,
					 addresses=None, user_request_id=None, image_url=None, data_uri=None):
	""" Create an applicant in the database.
	Args:
		first_name : Firstname of the applicant
		file_path : [Optional] data_uri or image_url or file_path
		last_name : [Optional] Surname of the applicant
		email : [Optional] Name.Surname@domain.com
		phone : [Optional] +911234567890
		dob : [Optional] 1995-04-29
		id_numbers : [Optional] can store aadhaar, pan, passport 
		addresses : [Optional] can store flat_number, building_number, building_name, street, sub_street, city, state, 
			postcode, line, line1, line2, line3 (optional)
		user_request_id : [Optional] user request id, supplied with response
		image_url : [Optional] data_uri or image_url or file_path
		data_uri : [Optional] data_uri or image_url or file_path

	Returns:
		create applicant in the database and returns HTTP status code
	"""
	url = "applicants/"

	if file_path:
		files = {'file_path': open(file_path, 'rb')}
	else:
		files = {}

	# create only one data field dict
	json = {'first_name': first_name, 'last_name': last_name, 'email': email,
			'phone': phone, 'dob': dob, 'id_numbers': id_numbers, 'addresses': addresses,
			'user_request_id': user_request_id}

	if image_url:
		json["image_url"] = image_url
	elif data_uri:
		json["data_uri"] = data_uri

	# call internal abstract API function
	response = request('POST', url, files=files, data=json)
	return response


def get_applicant(applicant_id=None):
	""" Get applicant data given an applicant id OR Get all applicant data if applicant id is not provided.
	Args:
		applicant_id : [Optional] if given, will return data for that applicant. 
			If not given, will return data of all applicants related to user.
			For ex, 3898cd8c-54ef-4b19-a5fd-2f0b8581c72c

	Returns:
		applicant data from the database and returns HTTP status code
	"""
	url = "applicants/"
	json = {'applicant_id': applicant_id}
	files = None

	# call internal abstract API function
	response = request('GET', url, files=files, json=json)
	return response


def delete_applicant(applicant_id):
	""" Delete an applicant from the database.

	Args:
		applicant_id : if given, will delete data for that applicant. 
			For ex, 3898cd8c-54ef-4b19-a5fd-2f0b8581c72c

	Returns:
		returns HTTP status code
	"""
	url = "applicants/"
	json = {'applicant_id': applicant_id}
	files = None

	# call internal abstract API function
	response = request('DELETE', url, files=files, json=json)
	return response


def modify_applicant(applicant_id, first_name, file_path=None, last_name=None, email=None, phone=None, dob=None,
					 id_numbers=None, addresses=None, user_request_id=None, image_url=None, data_uri=None):
	""" Modify an applicant from the database.

	Args:
		applicant_id : if given, will delete data for that applicant. 
			For ex, 3898cd8c-54ef-4b19-a5fd-2f0b8581c72c
		first_name : Firstname of the applicant
		file_path : [Optional] data_uri or image_url or file_path
		last_name : [Optional] Surname of the applicant
		email : [Optional] Name.Surname@domain.com
		phone : [Optional] +911234567890
		dob : [Optional] 1995-04-29
		id_numbers : [Optional] can store aadhaar, pan, passport 
		addresses : [Optional] can store flat_number, building_number, building_name, street, sub_street, city, state, 
			postcode, line, line1, line2, line3 (optional)
		user_request_id : [Optional] user request id, supplied with response
		image_url : [Optional] data_uri or image_url or file_path
		data_uri : [Optional] data_uri or image_url or file_path

	Returns:
		returns HTTP status code
	"""
	url = "applicants/"

	if file_path:
		files = {'file_path': open(file_path, 'rb')}
	else:
		files = {}

	# create only one data field dict
	json = {'applicant_id': applicant_id, 'first_name': first_name, 'last_name': last_name, 'email': email,
			'phone': phone, 'dob': dob, 'id_numbers': id_numbers, 'addresses': addresses,
			'user_request_id': user_request_id}

	if image_url:
		json["image_url"] = image_url
	elif data_uri:
		json["data_uri"] = data_uri

	# call internal abstract API function
	response = request('PUT', url, files=files, data=json, json=json)
	return response




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
File: reports.py
Description: Report section of the Sparshik KYC API.
"""

from .utils import request


def video_challenge(challenge_id, file_path, video_url=None, data_uri=None, user_request_id=None, intervals=None):
	""" Used to verify if video supplied by user has cleared challenges.

	Args:
		challenge_id : For ex, 63672fb8-c2bd-4160-aeed-7c2d5951f63b
		file_path : Path to File or Image or Data URL
		video_url : [Optional] data_uri or video_url or file_path ( one of them is required)
		data_uri : [Optional] data_uri or video_url or file_path ( one of them is required)
		user_request_id : [Optional] user request id, supplied with response
		intervals : [Optional] intervals in seconds that contains durations of challenge sections. 
			In example, first challenge runs from 0-5 seconds, second challenge from 5-10 seconds.

	Returns:
		video verification results and returns HTTP status code
	"""
	url = "reports/video_challenge"

	json = {'challenge_id': challenge_id, 'intervals': intervals, 'user_request_id': user_request_id}

	if file_path:
		files = {'file_path': open(file_path, 'rb')}
	else:
		files = {}

	if video_url:
		json["video_url"] = video_url
	elif data_uri:
		json["data_uri"] = data_uri

	# call internal abstract API function
	response = request('POST', url, files=files, data=json)
	return response


def document_face_similarity(document_id, file_path, data_uri=None, image_url=None, user_request_id=None):
	""" Compare face from an image against face from document stored in database.

	Args:
		document_id : For ex, 46d82a45-e8ff-474f-98dd-489f2ecdd683
		file_path : [Optional] data_uri or image_url or file_path
		data_uri : [Optional] data_uri or image_url or file_path ( one of them is required)
		image_url : [Optional] data_uri or image_url or file_path ( one of them is required)
		user_request_id : [Optional] user request id, supplied with response
		
	Returns:
		document and face verification results and returns HTTP status code
	"""
	url = "reports/facial_similarity_photo/document/"

	json = {'document_id': document_id, 'user_request_id': user_request_id}

	if file_path:
		files = {'file_path': open(file_path, 'rb')}
	else:
		files = {}

	if image_url:
		json["image_url"] = image_url
	elif data_uri:
		json["data_uri"] = data_uri

	# call internal abstract API function
	response = request('POST', url, files=files, data=json)
	return response


def image_similarity(file_path_1=None, data_uri_1=None, image_url_1=None, 
	file_path_2=None, data_uri_2=None, image_url_2=None, user_request_id=None):
	""" Compare two faces from file_path or data_uri or image_url.

	Args:
		file_path_1 : [Optional] Path to File or Image or Data URL
		data_uri_1 : [Optional] data_uri or image_url or file_path ( one of them is required)
		image_url_1 : [Optional] data_uri or image_url or file_path ( one of them is required)
		file_path_2 : [Optional] Path to File or Image or Data URL
		data_uri_2 : [Optional] data_uri or image_url or file_path ( one of them is required)
		image_url_2 : [Optional] data_uri or image_url or file_path ( one of them is required)
		user_request_id : [Optional] user request id, supplied with response
		
	Returns:
		face verification results and returns HTTP status code
	"""
	url = "reports/facial_similarity_photo/"

	json = {'user_request_id': user_request_id}

	if file_path_1 and file_path_2:
		files = {'file_path_1': open(file_path_1, 'rb') , 'file_path_2':open(file_path_2, 'rb')}
	else:
		files = {}

	if image_url_1 or image_url_2:
		json["image_url_1"] = image_url_1
		json["image_url_2"] = image_url_2
	elif data_uri_1 or data_uri_2:
		json["data_uri_1"] = data_uri_1
		json["data_uri_2"] = data_uri_2

	# call internal abstract API function
	response = request('POST', url, files=files, data=json)
	return response


def face_attributes(attributes, file_path=None, data_uri=None, image_url=None):
	""" Generate a report on specified attributes in faces.

	Args:
		attributes : specify which face attributes to receive.
			For ex, age,gender, smoker, alcohol,bmi, ethnicity, resident, 
			region, marital, education
		file_path : [Optional] data_uri or image_url or file_path ( one of them is required)
		data_uri : [Optional] data_uri or image_url or file_path ( one of them is required)
		image_url : [Optional] data_uri or image_url or file_path ( one of them is required)
		
	Returns:
		face attributes results and returns HTTP status code
	"""
	url = "reports/face_attributes"

	json = {"attributes": attributes}

	if file_path:
		files = {'file_path': open(file_path, 'rb')}
	else:
		files = {}

	if image_url:
		json["image_url"] = image_url
	elif data_uri:
		json["data_uri"] = data_uri

	# call internal abstract API function
	response = request('POST', url, files=files, data=json)
	return response


def video_image_similarity(video_file_path=None, video_data_uri=None, video_url=None, 
	image_file_path=None, image_data_uri=None, image_url=None, user_request_id=None, 
	interval=None):
	""" Compare face from a video and image.
	Args:
		video_file_path : [Optional] video_file_path or video_data_uri or video_url ( one of them is required)
		video_data_uri : [Optional] video_file_path or video_data_uri or video_url ( one of them is required)
		video_url : [Optional] video_file_path or video_data_uri or video_url ( one of them is required)
		image_file_path : [Optional] data_uri or image_url or file_path ( one of them is required)
		image_data_uri : [Optional] data_uri or image_url or file_path ( one of them is required)
		image_url : [Optional] data_uri or image_url or file_path ( one of them is required)
		user_request_id : [Optional] user request id, supplied with response
		interval : [Optional] interval in seconds that contains durations of challenge sections. 
			In example, first challenge runs from 0-5 seconds, second challenge from 5-10 seconds.
		
	Returns:
		comparison results from video and face with HTTP status code
	"""
	url = "reports/verify_face_similarity/"

	json = {'interval': interval , 'user_request_id': user_request_id}

	if video_file_path and image_file_path:
		files = {'video_file_path': open(video_file_path, 'rb'), 'image_file_path': open(image_file_path, 'rb')}
	else:
		files = {}

	if video_url or image_url:
		json["image_url"] = image_url
		json["video_url"] = video_url

	elif video_data_uri or image_data_uri:
		json["video_data_uri"] = video_data_uri
		json["image_data_uri"] = image_data_uri

	# call internal abstract API function
	response = request('POST', url, files=files, json=None)
	return response


def applicant_document_comparison(applicant_id, document_id, user_request_id=None):
	""" Can directly compare data filled in by applicant and document in database.

	Args:
		applicant_id : For ex, 3898cd8c-54ef-4b19-a5fd-2f0b8581c72c
		document_id : For ex, 46d82a45-e8ff-474f-98dd-489f2ecdd683
		user_request_id : [Optional] user request id, supplied with response
		
	Returns:
		applicant and document verification results and returns HTTP status code
	"""
	
	url = "reports/compare_applicant_document"
	files = None
	json = {'applicant_id': applicant_id , 'document_id': document_id, 'user_request_id': user_request_id}

	# call internal abstract API function
	response = request('POST', url, files=files, json=json)
	return response
